<?php
/**
 * Glow Loyalty API PHP Library
 *
 * Use this library to interface with Glow's API
 * https://www.glowloyalty.com/api
 *
 *  Example Usage:
 *  =========================
 *  $glow = new \Glow\Glow($api_key,$api_secret);
 *  $member = $glow->getMember(['email'=>'member@domain.com']);
 *
 */

namespace Glow;

class Glow
{
    // @var string The Glow API key and secret to be used for requests.
    protected $_api_key;
    protected $_api_secret;

    // @var string The base URL for the Glow API.
    protected $_api_base = 'https://www.glowloyalty.com/api/v1';

    /**
     * Prepare to make request
     * @param string $api_key    Your Glow API Key
     * @param string $api_secret Your Glow API Secret
     */
    public function __construct($api_key, $api_secret, $api_base=false)
    {
        //set API key and secret
        $this->_api_key = $api_key;
        $this->_api_secret = $api_secret;

        if ($api_base) {
            $this->_api_base = $api_base;
        }
    }

    /**
     * Get a list of members
     * @return Member Array of Objects
     */
    public function getMembers($data)
    {
        return $this->get('/members', $data);
    }

    /**
     * Get a member
     * @return Member Object
     */
    public function getMember($data)
    {
        return $this->get('/member', $data);
    }

    /**
    * Update a member
    * @return Member Object
    */
    public function updateMember($data)
    {
        return $this->post('/member', $data);
    }

    /**
     * Delete a member
     *
     * @param $data
     * @return mixed
     */
    public function deleteMember($data)
    {
        return $this->post('/delete-member', $data);
    }

    /**
     * Get a list of rewards
     * @return Rewards Array of Objects
     */
    public function getRewards($data)
    {
        return $this->get('/rewards', $data);
    }

    /**
     * Get a reward
     * @return Reward Object
     */
    public function getReward($data)
    {
        return $this->get('/reward', $data);
    }

    /**
    * Create a reward
    * @return Reward Object
    */
    public function createReward($data)
    {
        return $this->post('/create-reward', $data);
    }

    /**
     * Update the reward
     * @return Reward Object
     */
    public function updateReward($data)
    {
        return $this->post('/update-reward', $data);
    }

    /**
    * Delete a reward
    * @return Reward Object
    */
    public function deleteReward($data)
    {
        return $this->post('/delete-reward', $data);
    }

    /**
     * Redeem tge reward
     * @return DiscoutnCode Object
     */
    public function redeemReward($data)
    {
        return $this->post('/redeem-reward', $data);
    }

    /**
    * Get point log
    * @return PointLog Array of Objects
    */
    public function getPointLog($data)
    {
        return $this->get('/point-log', $data);
    }

    /**
    * Add or deduct points from a member
    * @return Member Array of Objects
    */
    public function adjustPoints($data)
    {
        return $this->post('/point-log', $data);
    }

    /**
     * Get a list of discount codes
     * @return DiscoutnCode Array of Objects
     */
    public function getDiscountCodes($data)
    {
        return $this->get('/discount-codes', $data);
    }

    /**
     * Get a discount code
     * @return Member Object
     */
    public function getDiscountCode($data)
    {
        return $this->get('/discount-code', $data);
    }

    /**
     * Get a list of discount codes
     * @return VipTier Array of Objects
     */
    public function getVipTiers()
    {
        return $this->get('/vip-tiers');
    }
   
    /**
    * Send POST request
    */
    public function post($endpoint, $params=array())
    {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('api_key: '.$this->_api_key ,'api_secret: '.$this->_api_secret));
        curl_setopt($ch, CURLOPT_URL, $this->_api_base.$endpoint);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_VERBOSE, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        curl_setopt(
            $ch,
            CURLOPT_POSTFIELDS,
            http_build_query($params)
        );
        // receive server response
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $server_output = curl_exec($ch);

        curl_close($ch);
        return json_decode($server_output);
    }
    /**
    * Send GET request
    */
    public function get($endpoint, $params=array())
    {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('api_key: '.$this->_api_key ,'api_secret: '.$this->_api_secret));
        $query = http_build_query($params);
        curl_setopt($ch, CURLOPT_URL, $this->_api_base.$endpoint.'?'.$query);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        $output=curl_exec($ch);

        curl_close($ch);
        return json_decode($output);
    }
}
